@@ -20,7 +20,7 @@
 
 """
 Module for BitcoinCash bech32 decoding/encoding.
-Reference: https://github.com/bitcoincashorg/bitcoincash.org/blob/master/spec/cashaddr.md.
+Reference: https://github.com/bitcoincashorg/bitcoincash.org/blob/master/spec/cashaddr.md
 """
 
 # Imports
@@ -34,7 +34,7 @@ class BchBech32Const:
 
     # Separator
     SEPARATOR: str = ":"
-    # Checkum length in bytes
+    # Checksum length in bytes
     CHECKSUM_BYTE_LEN: int = 8
     # Minimum data length in bytes
     DATA_MIN_BYTE_LEN: int = 2
@@ -51,7 +51,7 @@ class BchBech32Utils:
         Computes the polynomial modulus.
 
         Args:
-            values (list): List of polynomial coefficients
+            values (list[int]): List of polynomial coefficients
 
         Returns:
             int: Computed modulus
@@ -85,7 +85,7 @@ class BchBech32Utils:
             hrp (str): HRP
 
         Returns:
-            list: Expanded HRP values
+            list[int]: Expanded HRP values
         """
         # [lower 5 bits of each character] + [0]
         return [ord(x) & 0x1f for x in hrp] + [0]
@@ -97,11 +97,11 @@ class BchBech32Utils:
         Compute the checksum from the specified HRP and data.
 
         Args:
-            hrp (str)  : HRP
-            data (list): Data part
+            hrp (str)       : HRP
+            data (list[int]): Data part
 
         Returns:
-            list: Computed checksum
+            list[int]: Computed checksum
         """
 
         values = BchBech32Utils.HrpExpand(hrp) + data
@@ -115,8 +115,8 @@ class BchBech32Utils:
         Verify the checksum from the specified HRP and converted data characters.
 
         Args:
-            hrp  (str) : HRP
-            data (list): Data part
+            hrp  (str)      : HRP
+            data (list[int]): Data part
 
         Returns:
             bool: True if valid, false otherwise
@@ -130,8 +130,9 @@ class BchBech32Encoder(Bech32EncoderBase):
     It provides methods for encoding to Bitcoin Cash Bech32 format.
     """
 
-    @staticmethod
-    def Encode(hrp: str,
+    @classmethod
+    def Encode(cls,
+               hrp: str,
                net_ver: bytes,
                data: bytes) -> str:
         """
@@ -149,9 +150,9 @@ class BchBech32Encoder(Bech32EncoderBase):
             ValueError: If the data is not valid
         """
 
-        return BchBech32Encoder._EncodeBech32(hrp,
-                                              Bech32BaseUtils.ConvertToBase32(net_ver + data),
-                                              BchBech32Const.SEPARATOR)
+        return cls._EncodeBech32(hrp,
+                                 Bech32BaseUtils.ConvertToBase32(net_ver + data),
+                                 BchBech32Const.SEPARATOR)
 
     @staticmethod
     def _ComputeChecksum(hrp: str,
@@ -160,11 +161,11 @@ class BchBech32Encoder(Bech32EncoderBase):
         Compute the checksum from the specified HRP and data.
 
         Args:
-            hrp (str)  : HRP
-            data (list): Data part
+            hrp (str)       : HRP
+            data (list[int]): Data part
 
         Returns:
-            list: Computed checksum
+            list[int]: Computed checksum
         """
         return BchBech32Utils.ComputeChecksum(hrp, data)
 
@@ -175,8 +176,9 @@ class BchBech32Decoder(Bech32DecoderBase):
     It provides methods for decoding Bitcoin Cash Bech32 format.
     """
 
-    @staticmethod
-    def Decode(hrp: str,
+    @classmethod
+    def Decode(cls,
+               hrp: str,
                addr: str) -> Tuple[bytes, bytes]:
         """
         Decode from Bitcoin Cash Bech32.
@@ -186,7 +188,7 @@ class BchBech32Decoder(Bech32DecoderBase):
             addr (str): Address
 
         Returns:
-            tuple: Net version (index 0) and data (index 1)
+            tuple[bytes, bytes]: Net version (index 0) and data (index 1)
 
         Raises:
             ValueError: If the bech32 string is not valid
@@ -194,7 +196,9 @@ class BchBech32Decoder(Bech32DecoderBase):
         """
 
         # Decode string
-        hrp_got, data = BchBech32Decoder._DecodeBech32(addr, BchBech32Const.SEPARATOR, BchBech32Const.CHECKSUM_BYTE_LEN)
+        hrp_got, data = cls._DecodeBech32(addr,
+                                          BchBech32Const.SEPARATOR,
+                                          BchBech32Const.CHECKSUM_BYTE_LEN)
 
         # Check HRP
         if hrp != hrp_got:
@@ -217,8 +221,8 @@ class BchBech32Decoder(Bech32DecoderBase):
         Verify the checksum from the specified HRP and converted data characters.
 
         Args:
-            hrp  (str) : HRP
-            data (list): Data part
+            hrp  (str)      : HRP
+            data (list[int]): Data part
 
         Returns:
             bool: True if valid, false otherwise
