@@ -18,11 +18,7 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-"""
-Module with BIP32 base class.
-BIP-0032 reference: https://github.com/bitcoin/bips/blob/master/bip-0032.mediawiki.
-SLIP-0010 reference: https://github.com/satoshilabs/slips/blob/master/slip-0010.md.
-"""
+"""Module with BIP32 base class."""
 
 # Imports
 from __future__ import annotations
@@ -31,8 +27,9 @@ from typing import Optional, Union, Tuple
 from bip_utils.bip.bip32.bip32_ex import Bip32KeyError
 from bip_utils.bip.bip32.bip32_const import Bip32Const
 from bip_utils.bip.bip32.bip32_key_data import (
-    Bip32ChainCode, Bip32Depth, Bip32FingerPrint, Bip32KeyIndex, Bip32KeyNetVersions, Bip32KeyData
+    Bip32ChainCode, Bip32Depth, Bip32FingerPrint, Bip32KeyIndex, Bip32KeyData
 )
+from bip_utils.bip.bip32.bip32_key_net_ver import Bip32KeyNetVersions
 from bip_utils.bip.bip32.bip32_key_ser import Bip32KeyDeserializer
 from bip_utils.bip.bip32.bip32_keys import Bip32PrivateKey, Bip32PublicKey
 from bip_utils.bip.bip32.bip32_path import Bip32Path, Bip32PathParser
@@ -53,22 +50,20 @@ class Bip32BaseUtils:
     """Class container for BIP32 base utility functions."""
 
     @staticmethod
-    def HmacHalves(chain_code: Bip32ChainCode,
-                   data_bytes: bytes) -> Tuple[bytes, bytes]:
+    def HmacSha512Halves(key_bytes: bytes,
+                         data_bytes: bytes) -> Tuple[bytes, bytes]:
         """
         Calculate the HMAC-SHA512 of input data using the chain code as key.
         Returns a tuple of the left and right halves of the HMAC.
 
         Args:
-            chain_code (bytes): Chain code
+            key_bytes (bytes) : Key bytes
             data_bytes (bytes): Data bytes
 
         Returns:
             tuple[bytes, bytes]: Left and right halves of the HMAC
         """
-
-        # Use chain as HMAC key
-        hmac = CryptoUtils.HmacSha512(chain_code.ToBytes(), data_bytes)
+        hmac = CryptoUtils.HmacSha512(key_bytes, data_bytes)
         return hmac[:Bip32BaseConst.HMAC_HALF_BYTE_LEN], hmac[Bip32BaseConst.HMAC_HALF_BYTE_LEN:]
 
 
@@ -84,7 +79,6 @@ class Bip32Base(ABC):
 
     #
     # Class methods for construction
-    # They are meant to be called by children classes, that's why they are protected
     #
 
     @classmethod
@@ -105,32 +99,9 @@ class Bip32Base(ABC):
             ValueError: If the seed is too short
             Bip32KeyError: If the seed is not suitable for master key generation
         """
-        curve_type = cls.CurveType()
-        curve = EllipticCurveGetter.FromType(curve_type)
-        priv_key_cls = curve.PrivateKeyClass()
-
-        # Check seed length
-        if len(seed_bytes) * 8 < Bip32BaseConst.SEED_MIN_BIT_LEN:
+        if not cls._IsSeedLengthValid(seed_bytes):
             raise ValueError(f"Seed length is too small, it shall be at least {Bip32BaseConst.SEED_MIN_BIT_LEN} bit")
-
-        # Compute HMAC, retry if the resulting private key is not valid
-        hmac = b""
-        hmac_data = seed_bytes
-        success = False
-
-        while not success:
-            hmac = CryptoUtils.HmacSha512(cls._MasterKeyHmacKey(), hmac_data)
-            # If private key is not valid, the new HMAC data is the current HMAC
-            success = priv_key_cls.IsValidBytes(hmac[:Bip32BaseConst.HMAC_HALF_BYTE_LEN])
-            if not success:
-                hmac_data = hmac
-
-        # Create BIP32 by splitting the HMAC into two 32-byte sequences
-        return cls(priv_key=hmac[:Bip32BaseConst.HMAC_HALF_BYTE_LEN],
-                   pub_key=None,
-                   chain_code=Bip32ChainCode(hmac[Bip32BaseConst.HMAC_HALF_BYTE_LEN:]),
-                   curve_type=curve_type,
-                   key_net_ver=key_net_ver)
+        return cls._FromSeed(seed_bytes, key_net_ver)
 
     @classmethod
     def FromSeedAndPath(cls,
@@ -199,24 +170,23 @@ class Bip32Base(ABC):
 
         return cls(priv_key=key_bytes if not is_public else None,
                    pub_key=key_bytes if is_public else None,
-                   chain_code=key_data.ChainCode(),
+                   key_data=key_data,
                    curve_type=cls.CurveType(),
-                   depth=key_data.Depth(),
-                   index=key_data.Index(),
-                   fprint=key_data.ParentFingerPrint(),
-                   key_net_ver=key_data.KeyNetVersions())
+                   key_net_ver=key_net_ver)
 
     @classmethod
     def FromPrivateKey(cls,
                        priv_key: Union[bytes, IPrivateKey],
+                       key_data: Bip32KeyData = Bip32KeyData(),
                        key_net_ver: Bip32KeyNetVersions = Bip32Const.MAIN_NET_KEY_NET_VERSIONS) -> Bip32Base:
         """
-        Create a Bip32 object from the specified private key.
-        The key will be considered a master key with the chain code set to zero,
-        since there is no way to recover the key derivation data.
+        Create a Bip32 object from the specified private key and derivation data.
+        If only the private key bytes are specified, the key will be considered a master key with
+        the chain code set to zero, since there is no way to recover the key derivation data.
 
         Args:
             priv_key (bytes or IPrivateKey)         : Private key
+            key_data (Bip32KeyData object, optional): Key data (default: all zeros)
             key_net_ver (Bip32KeyNetVersions object): Bip32KeyNetVersions object (BIP32 main net version by default)
 
         Returns:
@@ -227,21 +197,23 @@ class Bip32Base(ABC):
         """
         return cls(priv_key=priv_key,
                    pub_key=None,
-                   chain_code=Bip32ChainCode(),
+                   key_data=key_data,
                    curve_type=cls.CurveType(),
                    key_net_ver=key_net_ver)
 
     @classmethod
     def FromPublicKey(cls,
                       pub_key: Union[bytes, IPublicKey],
+                      key_data: Bip32KeyData = Bip32KeyData(),
                       key_net_ver: Bip32KeyNetVersions = Bip32Const.MAIN_NET_KEY_NET_VERSIONS) -> Bip32Base:
         """
-        Create a Bip32 object from the specified public key.
-        The key will be considered a public master key with the chain code set to zero,
-        since there is no way to recover the key derivation data.
+        Create a Bip32 object from the specified public key and derivation data.
+        If only the the public key bytes are specified, the key will be considered a master key with
+        the chain code set to zero, since there is no way to recover the key derivation data.
 
         Args:
             pub_key (bytes or IPublicKey)           : Public key
+            key_data (Bip32KeyData object, optional): Key data (default: all zeros)
             key_net_ver (Bip32KeyNetVersions object): Bip32KeyNetVersions object (BIP32 main net version by default)
 
         Returns:
@@ -252,7 +224,7 @@ class Bip32Base(ABC):
         """
         return cls(priv_key=None,
                    pub_key=pub_key,
-                   chain_code=Bip32ChainCode(),
+                   key_data=key_data,
                    curve_type=cls.CurveType(),
                    key_net_ver=key_net_ver)
 
@@ -263,11 +235,8 @@ class Bip32Base(ABC):
     def __init__(self,
                  priv_key: Optional[Union[bytes, IPrivateKey]],
                  pub_key: Optional[Union[bytes, IPublicKey]],
-                 chain_code: Bip32ChainCode,
+                 key_data: Bip32KeyData,
                  curve_type: EllipticCurveTypes,
-                 depth: Bip32Depth = Bip32Depth(0),
-                 index: Bip32KeyIndex = Bip32KeyIndex(0),
-                 fprint: Bip32FingerPrint = Bip32FingerPrint(),
                  key_net_ver: Bip32KeyNetVersions = Bip32Const.MAIN_NET_KEY_NET_VERSIONS) -> None:
         """
         Construct class.
@@ -276,12 +245,8 @@ class Bip32Base(ABC):
             priv_key (bytes or IPrivateKey)                   : Private key (None for a public-only object)
             pub_key (bytes or IPublicKey)                     : Public key (only needed for a public-only object)
                                                                 If priv_key is not None, it'll be discarded
-            chain_code (Bip32ChainCode object)                : Chain code
+            key_data (Bip32KeyData object)                    : Key data
             curve_type (EllipticCurveTypes)                   : Elliptic curve type
-            depth (Bip32Depth object, optional)               : Child depth, parent increments its own by one when
-                                                                assigning this (default: 0)
-            index (Bip32KeyIndex object, optional)            : Child index (default: 0)
-            fprint (Bip32FingerPrint object, optional)        : Parent fingerprint (default: master key)
             key_net_ver (Bip32KeyNetVersions object, optional): Bip32KeyNetVersions object (Bip32 main net by default)
 
         Raises:
@@ -297,13 +262,11 @@ class Bip32Base(ABC):
             if not isinstance(pub_key, bytes) and not isinstance(pub_key, curve.PublicKeyClass()):
                 raise Bip32KeyError(f"Invalid public key class, a {curve.Name()} key is required")
 
-        # Key data
-        key_data = Bip32KeyData(key_net_ver, depth, index, chain_code, fprint)
-
         # Private key object
         if priv_key is not None:
             self.m_priv_key = Bip32PrivateKey.FromBytesOrKeyObject(priv_key,
                                                                    key_data,
+                                                                   key_net_ver,
                                                                    curve_type)
             self.m_pub_key = self.m_priv_key.PublicKey()
         # Public-only object
@@ -313,6 +276,7 @@ class Bip32Base(ABC):
             self.m_priv_key = None
             self.m_pub_key = Bip32PublicKey.FromBytesOrKeyObject(pub_key,
                                                                  key_data,
+                                                                 key_net_ver,
                                                                  curve_type)
 
     def ChildKey(self,
@@ -330,9 +294,7 @@ class Bip32Base(ABC):
         Raises:
             Bip32KeyError: If the index results in an invalid key
         """
-        if isinstance(index, int):
-            index = Bip32KeyIndex(index)
-
+        index = self.__GetIndex(index)
         return self._ValidateAndCkdPriv(index) if not self.IsPublicOnly() else self._ValidateAndCkdPub(index)
 
     def DerivePath(self,
@@ -349,9 +311,7 @@ class Bip32Base(ABC):
         Raises:
             Bip32PathError: If the path is not valid
         """
-        if isinstance(path, str):
-            path = Bip32PathParser.Parse(path)
-
+        path = self.__GetPath(path)
         bip32_obj = self
         # Derive children keys
         for path_elem in path:
@@ -404,7 +364,7 @@ class Bip32Base(ABC):
         Returns:
             Bip32KeyNetVersions object: Bip32KeyNetVersions object
         """
-        return self.m_pub_key.Data().KeyNetVersions()
+        return self.m_pub_key.KeyNetVersions()
 
     def Depth(self) -> Bip32Depth:
         """
@@ -455,6 +415,59 @@ class Bip32Base(ABC):
     # Protected methods
     #
 
+    @staticmethod
+    def _IsSeedLengthValid(seed_bytes: bytes) -> bool:
+        """
+        Get if the seed length is valid.
+
+        Args:
+            seed_bytes (bytes): Seed bytes
+
+        Returns:
+            bool: True if valid, false otherwise
+        """
+        return len(seed_bytes) * 8 >= Bip32BaseConst.SEED_MIN_BIT_LEN
+
+    @classmethod
+    def _FromSeed(cls,
+                  seed_bytes: bytes,
+                  key_net_ver: Bip32KeyNetVersions) -> Bip32Base:
+        """
+        Create a Bip32 object from the specified seed (e.g. BIP39 seed).
+
+        Args:
+            seed_bytes (bytes)                      : Seed bytes
+            key_net_ver (Bip32KeyNetVersions object): Bip32KeyNetVersions object
+
+        Returns:
+            Bip32Base object: Bip32Base object
+
+        Raises:
+            ValueError: If the seed is too short
+            Bip32KeyError: If the seed is not suitable for master key generation
+        """
+        curve_type = cls.CurveType()
+        priv_key_cls = EllipticCurveGetter.FromType(curve_type).PrivateKeyClass()
+
+        # Compute HMAC, retry if the resulting private key is not valid
+        hmac = b""
+        hmac_data = seed_bytes
+        success = False
+
+        while not success:
+            hmac = CryptoUtils.HmacSha512(cls._MasterKeyHmacKey(), hmac_data)
+            # If private key is not valid, the new HMAC data is the current HMAC
+            success = priv_key_cls.IsValidBytes(hmac[:Bip32BaseConst.HMAC_HALF_BYTE_LEN])
+            if not success:
+                hmac_data = hmac
+
+        # Create BIP32 by splitting the HMAC into two 32-byte sequences
+        return cls(priv_key=hmac[:Bip32BaseConst.HMAC_HALF_BYTE_LEN],
+                   pub_key=None,
+                   key_data=Bip32KeyData(chain_code=hmac[Bip32BaseConst.HMAC_HALF_BYTE_LEN:]),
+                   curve_type=curve_type,
+                   key_net_ver=key_net_ver)
+
     def _ValidateAndCkdPriv(self,
                             index: Bip32KeyIndex) -> Bip32Base:
         """
@@ -501,6 +514,36 @@ class Bip32Base(ABC):
 
         return self._CkdPub(index)
 
+    #
+    # Private methods
+    #
+
+    @staticmethod
+    def __GetIndex(index: Union[int, Bip32KeyIndex]) -> Bip32KeyIndex:
+        """
+        Get index object.
+
+        Args:
+            index (int or Bip32KeyIndex): Index
+
+        Returns:
+            Bip32KeyIndex object: Bip32KeyIndex object
+        """
+        return Bip32KeyIndex(index) if isinstance(index, int) else index
+
+    @staticmethod
+    def __GetPath(path: Union[str, Bip32Path]) -> Bip32Path:
+        """
+        Get path object.
+
+        Args:
+            path (str or Bip32Path): Path
+
+        Returns:
+            Bip32Path object: Bip32Path object
+        """
+        return Bip32PathParser.Parse(path) if isinstance(path, str) else path
+
     #
     # Abstract methods
     #
