@@ -25,8 +25,9 @@ from typing import Optional, Tuple
 from bip_utils.base58 import Base58Decoder, Base58Encoder
 from bip_utils.bip.bip32.bip32_ex import Bip32KeyError
 from bip_utils.bip.bip32.bip32_key_data import (
-    Bip32ChainCode, Bip32Depth, Bip32FingerPrint, Bip32KeyIndex, Bip32KeyNetVersions, Bip32KeyData
+    Bip32ChainCode, Bip32Depth, Bip32FingerPrint, Bip32KeyIndex, Bip32KeyData
 )
+from bip_utils.bip.bip32.bip32_key_net_ver import Bip32KeyNetVersions
 from bip_utils.ecc import IPublicKey, IPrivateKey
 from bip_utils.utils.misc import BytesUtils
 
@@ -34,8 +35,10 @@ from bip_utils.utils.misc import BytesUtils
 class Bip32KeyDeserConst:
     """Class container for BIP32 key serialize constants."""
 
-    # Extended key length in bytes
-    EXTENDED_KEY_BYTE_LEN: int = 78
+    # Extended public key length in bytes
+    EXTENDED_PUB_KEY_BYTE_LEN: int = 78
+    # Extended private key length in bytes
+    EXTENDED_PRIV_KEY_BYTE_LEN: Tuple[int, int] = (78, 110)
 
 
 class Bip32KeyDeserializer:
@@ -75,10 +78,6 @@ class Bip32KeyDeserializer:
         # Decode key
         ex_key_bytes = Base58Decoder.CheckDecode(self.m_key_str)
 
-        # Check length
-        if len(ex_key_bytes) != Bip32KeyDeserConst.EXTENDED_KEY_BYTE_LEN:
-            raise Bip32KeyError(f"Invalid extended key (wrong length: {len(ex_key_bytes)})")
-
         # Get if key is public/private depending on net version
         key_net_ver_got = ex_key_bytes[:Bip32KeyNetVersions.Length()]
         if key_net_ver_got == key_net_ver.Public():
@@ -90,14 +89,19 @@ class Bip32KeyDeserializer:
                 f"Invalid extended key (wrong net version: {BytesUtils.ToHexString(key_net_ver_got)})"
             )
 
+        # Check length
+        if self.m_is_public and len(ex_key_bytes) != Bip32KeyDeserConst.EXTENDED_PUB_KEY_BYTE_LEN:
+            raise Bip32KeyError(f"Invalid extended public key (wrong length: {len(ex_key_bytes)})")
+        if not self.m_is_public and len(ex_key_bytes) not in Bip32KeyDeserConst.EXTENDED_PRIV_KEY_BYTE_LEN:
+            raise Bip32KeyError(f"Invalid extended private key (wrong length: {len(ex_key_bytes)})")
+
         # De-serialize key
         depth = ex_key_bytes[4]
         fprint = ex_key_bytes[5:9]
         index = BytesUtils.ToInteger(ex_key_bytes[9:13])
         chain_code = ex_key_bytes[13:45]
-        self.m_key_bytes = ex_key_bytes[45:78]
-        self.m_key_data = Bip32KeyData(key_net_ver,
-                                       Bip32Depth(depth),
+        self.m_key_bytes = ex_key_bytes[45:]
+        self.m_key_data = Bip32KeyData(Bip32Depth(depth),
                                        Bip32KeyIndex(index),
                                        Bip32ChainCode(chain_code),
                                        Bip32FingerPrint(fprint))
@@ -130,19 +134,21 @@ class Bip32PrivateKeySerializer:
 
     @staticmethod
     def Serialize(priv_key: IPrivateKey,
-                  key_data: Bip32KeyData) -> str:
+                  key_data: Bip32KeyData,
+                  key_net_ver: Bip32KeyNetVersions) -> str:
         """
         Serialize a private key.
 
         Args:
-            priv_key (IPrivateKey object): IPrivateKey object
-            key_data (BipKeyData object) : Key data
+            priv_key (IPrivateKey object)           : IPrivateKey object
+            key_data (BipKeyData object)            : Key data
+            key_net_ver (Bip32KeyNetVersions object): Key net versions
 
         Returns:
             str: Serialized private key
         """
         return Bip32KeySerializer.Serialize(b"\x00" + priv_key.Raw().ToBytes(),
-                                            key_data.KeyNetVersions().Private(),
+                                            key_net_ver.Private(),
                                             key_data.Depth(),
                                             key_data.Index(),
                                             key_data.ChainCode(),
@@ -157,19 +163,21 @@ class Bip32PublicKeySerializer:
 
     @staticmethod
     def Serialize(pub_key: IPublicKey,
-                  key_data: Bip32KeyData) -> str:
+                  key_data: Bip32KeyData,
+                  key_net_ver: Bip32KeyNetVersions) -> str:
         """
         Serialize the a public key.
 
         Args:
-            pub_key (IPublicKey object) : IPublicKey object
-            key_data (BipKeyData object): Key data
+            pub_key (IPublicKey object)             : IPublicKey object
+            key_data (BipKeyData object)            : Key data
+            key_net_ver (Bip32KeyNetVersions object): Key net versions
 
         Returns:
             str: Serialized public key
         """
         return Bip32KeySerializer.Serialize(pub_key.RawCompressed().ToBytes(),
-                                            key_data.KeyNetVersions().Public(),
+                                            key_net_ver.Public(),
                                             key_data.Depth(),
                                             key_data.Index(),
                                             key_data.ChainCode(),
