@@ -27,11 +27,11 @@ from abc import ABC, abstractmethod
 from enum import IntEnum, unique
 from functools import lru_cache
 from typing import Union
-from bip_utils.bip.bip32 import Bip32Base, Bip32Utils
+from bip_utils.bip.bip32 import Bip32Base, Bip32Utils, Bip32KeyData
 from bip_utils.bip.bip44_base.bip44_base_ex import Bip44DepthError
 from bip_utils.bip.bip44_base.bip44_keys import Bip44PublicKey, Bip44PrivateKey
 from bip_utils.bip.conf.common import BipCoins, BipCoinConf
-from bip_utils.ecc import IPrivateKey
+from bip_utils.ecc import IPublicKey, IPrivateKey
 
 
 @unique
@@ -118,15 +118,17 @@ class Bip44Base(ABC):
     @classmethod
     def _FromPrivateKey(cls,
                         priv_key: Union[bytes, IPrivateKey],
-                        coin_conf: BipCoinConf) -> Bip44Base:
+                        coin_conf: BipCoinConf,
+                        key_data: Bip32KeyData) -> Bip44Base:
         """
-        Create a Bip object from the specified private key.
-        The key will be considered a master key with the chain code set to zero,
-        since there is no way to recover the key derivation data.
+        Create a Bip object from the specified private key and derivation data.
+        If only the private key bytes are specified, the key will be considered a master key with
+        the chain code set to zero, since there is no way to recover the key derivation data.
 
         Args:
             priv_key (bytes or IPrivateKey): Private key
             coin_conf (BipCoinConf)        : BipCoinConf object
+            key_data (Bip32KeyData object) : Key data
 
         Returns:
             Bip object: Bip object
@@ -136,7 +138,35 @@ class Bip44Base(ABC):
         """
         bip32_cls = coin_conf.Bip32Class()
         return cls(bip32_cls.FromPrivateKey(priv_key,
-                                            key_net_ver=coin_conf.KeyNetVersions()),
+                                            key_data,
+                                            coin_conf.KeyNetVersions()),
+                   coin_conf)
+
+    @classmethod
+    def _FromPublicKey(cls,
+                       pub_key: Union[bytes, IPublicKey],
+                       coin_conf: BipCoinConf,
+                       key_data: Bip32KeyData) -> Bip44Base:
+        """
+        Create a Bip object from the specified public key and derivation data.
+        If only the public key bytes are specified, the key will be considered an account key with
+        the chain code set to zero, since there is no way to recover the key derivation data.
+
+        Args:
+            pub_key (bytes or IPublicKey)  : Public key
+            coin_conf (BipCoinConf)        : BipCoinConf object
+            key_data (Bip32KeyData object) : Key data
+
+        Returns:
+            Bip object: Bip object
+
+        Raises:
+            Bip32KeyError: If the key is not valid
+        """
+        bip32_cls = coin_conf.Bip32Class()
+        return cls(bip32_cls.FromPublicKey(pub_key,
+                                           key_data,
+                                           coin_conf.KeyNetVersions()),
                    coin_conf)
 
     #
@@ -185,9 +215,6 @@ class Bip44Base(ABC):
 
         Returns:
             Bip44PublicKey object: Bip44PublicKey object
-
-        Raises:
-            Bip32KeyError: If the key constructed from the bytes is not valid
         """
         return Bip44PublicKey(self.m_bip32.PublicKey(),
                               self.m_coin_conf)
@@ -201,11 +228,20 @@ class Bip44Base(ABC):
             Bip44PrivateKey object: Bip44PrivateKey object
 
         Raises:
-            Bip32KeyError: If the Bip32 object is public-only or the constructed key is not valid
+            Bip32KeyError: If the Bip32 object is public-only
         """
         return Bip44PrivateKey(self.m_bip32.PrivateKey(),
                                self.m_coin_conf)
 
+    def Bip32Object(self) -> Bip32Base:
+        """
+        Return the BIP32 object.
+
+        Returns:
+            Bip32Object object: Bip32Object object
+        """
+        return self.m_bip32
+
     def CoinConf(self) -> BipCoinConf:
         """
         Get coin configuration.
@@ -479,21 +515,47 @@ class Bip44Base(ABC):
     @abstractmethod
     def FromPrivateKey(cls,
                        priv_key: Union[bytes, IPrivateKey],
-                       coin_type: BipCoins) -> Bip44Base:
+                       coin_type: BipCoins,
+                       key_data: Bip32KeyData) -> Bip44Base:
         """
-        Create a Bip object from the specified private key.
-        The key will be considered a master key with the chain code set to zero,
-        since there is no way to recover the key derivation data.
+        Create a Bip object from the specified private key and derivation data.
+        If only the private key bytes are specified, the key will be considered a master key with
+        the chain code set to zero, since there is no way to recover the key derivation data.
 
         Args:
             priv_key (bytes or IPrivateKey): Private key
-            coin_type (BipCoins)           : Coin type (the type depends on the specific child class)
+            coin_type (BipCoins)           : Coin type, shall be a Bip44Coins enum
+            key_data (Bip32KeyData object) : Key data
 
         Returns:
             Bip object: Bip object
 
         Raises:
-            TypeError: If coin type is not of the correct type
+            TypeError: If coin type is not a Bip44Coins enum
+            Bip32KeyError: If the key is not valid
+        """
+
+    @classmethod
+    @abstractmethod
+    def FromPublicKey(cls,
+                      pub_key: Union[bytes, IPublicKey],
+                      coin_type: BipCoins,
+                      key_data: Bip32KeyData) -> Bip44Base:
+        """
+        Create a Bip object from the specified public key and derivation data.
+        If only the public key bytes are specified, the key will be considered an account key with
+        the chain code set to zero, since there is no way to recover the key derivation data.
+
+        Args:
+            pub_key (bytes or IPublicKey) : Public key
+            coin_type (BipCoins)          : Coin type, shall be a Bip44Coins enum
+            key_data (Bip32KeyData object): Key data
+
+        Returns:
+            Bip object: Bip object
+
+        Raises:
+            TypeError: If coin type is not a Bip44Coins enum
             Bip32KeyError: If the key is not valid
         """
 
