@@ -25,11 +25,11 @@ Reference: https://github.com/bitcoin/bips/blob/master/bip-0049.mediawiki
 
 # Imports
 from typing import Union
-from bip_utils.bip.bip32 import Bip32Utils
-from bip_utils.bip.bip44_base import Bip44Changes, Bip44Base
+from bip_utils.bip.bip32 import Bip32Utils, Bip32KeyData
+from bip_utils.bip.bip44_base import Bip44Changes, Bip44Levels, Bip44Base
 from bip_utils.bip.conf.bip49 import Bip49ConfGetter
 from bip_utils.bip.conf.common import BipCoins
-from bip_utils.ecc import IPrivateKey
+from bip_utils.ecc import IPublicKey, IPrivateKey
 
 
 class Bip49Const:
@@ -103,15 +103,17 @@ class Bip49(Bip44Base):
     @classmethod
     def FromPrivateKey(cls,
                        priv_key: Union[bytes, IPrivateKey],
-                       coin_type: BipCoins) -> Bip44Base:
+                       coin_type: BipCoins,
+                       key_data: Bip32KeyData = Bip32KeyData()) -> Bip44Base:
         """
-        Create a Bip object from the specified private key.
-        The key will be considered a master key with the chain code set to zero,
-        since there is no way to recover the key derivation data.
+        Create a Bip object from the specified private key and derivation data.
+        If only the private key bytes are specified, the key will be considered a master key with
+        the chain code set to zero, since there is no way to recover the key derivation data.
 
         Args:
-            priv_key (bytes or IPrivateKey): Private key
-            coin_type (BipCoins)           : Coin type, shall be a Bip49Coins enum
+            priv_key (bytes or IPrivateKey)         : Private key
+            coin_type (BipCoins)                    : Coin type, shall be a Bip49Coins enum
+            key_data (Bip32KeyData object, optional): Key data (default: all zeros)
 
         Returns:
             Bip object: Bip object
@@ -123,7 +125,36 @@ class Bip49(Bip44Base):
 
         # Bip49ConfGetter already checks the enum type
         return cls._FromPrivateKey(priv_key,
-                                   Bip49ConfGetter.GetConfig(coin_type))
+                                   Bip49ConfGetter.GetConfig(coin_type),
+                                   key_data)
+
+    @classmethod
+    def FromPublicKey(cls,
+                      pub_key: Union[bytes, IPublicKey],
+                      coin_type: BipCoins,
+                      key_data: Bip32KeyData = Bip32KeyData(depth=Bip44Levels.ACCOUNT)) -> Bip44Base:
+        """
+        Create a Bip object from the specified public key and derivation data.
+        If only the public key bytes are specified, the key will be considered an account key with
+        the chain code set to zero, since there is no way to recover the key derivation data.
+
+        Args:
+            pub_key (bytes or IPublicKey)           : Public key
+            coin_type (BipCoins)                    : Coin type, shall be a Bip44Coins enum
+            key_data (Bip32KeyData object, optional): Key data (default: all zeros with account depth)
+
+        Returns:
+            Bip object: Bip object
+
+        Raises:
+            TypeError: If coin type is not a Bip44Coins enum
+            Bip32KeyError: If the key is not valid
+        """
+
+        # Bip49ConfGetter already checks the enum type
+        return cls._FromPublicKey(pub_key,
+                                  Bip49ConfGetter.GetConfig(coin_type),
+                                  key_data)
 
     #
     # Override methods
