@@ -18,7 +18,7 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-"""Module for Monero mnemonic entropy generation."""
+"""Module for Monero entropy generation."""
 
 # Imports
 from enum import IntEnum, unique
@@ -46,14 +46,14 @@ class MoneroEntropyGeneratorConst:
 
 class MoneroEntropyGenerator(EntropyGenerator):
     """
-    Entropy generator class.
+    Monero entropy generator class.
     It generates random entropy bytes with the specified length.
     """
 
     def __init__(self,
                  bits_len: Union[int, MoneroEntropyBitLen]) -> None:
         """
-        Construct class by specifying the bits length.
+        Construct class.
 
         Args:
             bits_len (int or MoneroEntropyBitLen): Entropy length in bits
