@@ -31,7 +31,6 @@ from Crypto.Protocol.KDF import scrypt
 from bip_utils.utils.misc.algo import AlgoUtils
 
 
-HASHLIB_USE_RIPEMD160: bool = "ripemd160" in hashlib.algorithms_available
 HASHLIB_USE_SHA512_256: bool = "sha512_256" in hashlib.algorithms_available
 
 
@@ -144,6 +143,21 @@ class CryptoUtils:
         """
         return hmac.new(AlgoUtils.Encode(key), AlgoUtils.Encode(data), hashlib.sha512).digest()
 
+    @staticmethod
+    def HmacSha256(key: Union[bytes, str],
+                   data: Union[bytes, str]) -> bytes:
+        """
+        Compute the HMAC-SHA256 of the specified bytes with the specified key.
+
+        Args:
+            key (str or bytes) : Key
+            data (str or bytes): Data
+
+        Returns:
+            bytes: Computed HMAC-SHA256
+        """
+        return hmac.new(AlgoUtils.Encode(key), AlgoUtils.Encode(data), hashlib.sha256).digest()
+
     @staticmethod
     def Pbkdf2HmacSha512(password: Union[bytes, str],
                          salt: Union[bytes, str],
@@ -203,9 +217,6 @@ class CryptoUtils:
         Returns:
             bytes: Computed RIPEMD-160
         """
-        if HASHLIB_USE_RIPEMD160:
-            return hashlib.new("ripemd160", AlgoUtils.Encode(data)).digest()
-        # Use Cryptodome if not implemented in hashlib
         h = RIPEMD160.new()
         h.update(AlgoUtils.Encode(data))
         return h.digest()
@@ -218,8 +229,6 @@ class CryptoUtils:
         Returns:
             int: RIPEMD-160 size in bytes
         """
-        if HASHLIB_USE_RIPEMD160:
-            return hashlib.new("ripemd160").digest_size
         return RIPEMD160.digest_size
 
     @staticmethod
